==> ejc-profillreport-api-3.0.0-20231106.005528-23-sources.jar: com/ejianc/business/profillreport/vo/DeviationVO.java <==
package com.ejianc.business.profillreport.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工期情况进度偏差
 * 
 * @author generator
 * 
 */
public class DeviationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long contractId; // 合同ID
    private String billCode; // 零工单号
    private String contractName; // 合同名称


    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Integer billState; // 单据状态（审批必须字段）
    private Integer projectDelay; // 是否存在非我方原因导致的工期延误(1:是，2：否)
    private Integer durationVisa; // 是否办理工期签证(1:是，2：否)
    private String reason; // 事由
    

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getProjectDelay() {
        return projectDelay;
    }

    public void setProjectDelay(Integer projectDelay) {
        this.projectDelay = projectDelay;
    }
    public Integer getDurationVisa() {
        return durationVisa;
    }

    public void setDurationVisa(Integer durationVisa) {
        this.durationVisa = durationVisa;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    
}

==> ejc-profillreport-api-3.0.0-20251013.062011-60-sources.jar: com/ejianc/business/profillreport/vo/DeviationVO.java <==
package com.ejianc.business.profillreport.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工期情况进度偏差
 * 
 * @author generator
 * 
 */
public class DeviationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long contractId; // 合同ID
    private String billCode; // 零工单号
    private String contractName; // 合同名称


    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Integer billState; // 单据状态（审批必须字段）
    private Integer projectDelay; // 是否存在非我方原因导致的工期延误(1:是，2：否)
    private Integer durationVisa; // 是否办理工期签证(1:是，2：否)
    private String reason; // 事由
    

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getProjectDelay() {
        return projectDelay;
    }

    public void setProjectDelay(Integer projectDelay) {
        this.projectDelay = projectDelay;
    }
    public Integer getDurationVisa() {
        return durationVisa;
    }

    public void setDurationVisa(Integer durationVisa) {
        this.durationVisa = durationVisa;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    
}
